==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/advancedslideshow/plugin/kipiplugin_advancedslideshow.desktop.cmake <==
[Desktop Entry]
Name=Advanced Slideshow
Name[ast]=Presentación de diapositives avanzaes
Name[bg]=Подробна прожекция
Name[ca]=Passi de diapositives avançat
Name[ca@valencia]=Passe de diapositives avançat
Name[cs]=Pokročilé promítání
Name[da]=Avanceret diasshow
Name[de]=Erweiterte Diaschau
Name[el]=Προχωρημένη προβολή διαφανειών
Name[en_GB]=Advanced Slideshow
Name[es]=Presentación avanzada
Name[et]=Täiustatud slaidiseanss
Name[eu]=Diapositiba-aurkezpen aurreratua
Name[fi]=Advanced Slideshow
Name[fr]=Diaporama avancé
Name[ga]=Ardtaispeántas Sleamhnán
Name[gl]=Presentación avanzada
Name[hu]=Speciális diavetítés
Name[is]=Ítarlegri skyggnusýning
Name[it]=Presentazione avanzata
Name[ja]=高度なスライドショー
Name[km]=ការ​បញ្ចាំង​ស្លាយ​កម្រិត​ខ្ពស់
Name[lv]=Paplašinātā slīdrāde
Name[nb]=Avansert bildeframvisning
Name[nds]=Verwiedert Diaschau...
Name[nl]=Geavanceerde diavoorstelling
Name[pa]=ਮਾਹਰ ਸਲਾਈਡ-ਸ਼ੋ
Name[pl]=Zaawansowany pokaz slajdów
Name[pt]=Apresentação Avançada
Name[pt_BR]=Apresentação de slides avançada
Name[ro]=Diaporamă avansată
Name[ru]=Многофункциональное слайд-шоу
Name[sk]=Pokročilá prezentácia
Name[sl]=Napredna predstavitev
Name[sq]=Shfaqje e Avancuar
Name[sv]=Avancerat bildspel
Name[th]=การนำเสนอภาพขั้นสูง
Name[tr]=Gelişmiş Slayt Gösterisi
Name[uk]=Показ слайдів з додатковими можливостями
Name[x-test]=xxAdvanced Slideshowxx
Name[zh_CN]=高级幻灯片
Name[zh_TW]=進階投影片放映
Comment=A tool to slide images with 2D and 3D effects using OpenGL
Comment[ast]=Una ferramienta pa diapositives con efeutos en 2D y 3D emplegando OpenGL
Comment[bg]=Инструмент за прожекции на изображения с дву- и итриизмерни ефекти
Comment[ca]=Una eina per fer dispositives d'imatges amb efectes 2D i 3D utilitzant l'OpenGL
Comment[ca@valencia]=Una eina per fer dispositives d'imatges amb efectes 2D i 3D utilitzant l'OpenGL
Comment[cs]=Nástroj na prohlížení obrázků s 2D a 3D efekty pomocí OpenGL
Comment[da]=Et værktøj til at vise et diasshow med 2D- og 3D-effekter vha. OpenGL
Comment[de]=Ein Werkzeug, um Bilder in einer Diaschau mit 2D- und 3D-Effekten anzuzeigen.
Comment[el]=Εργαλείο προβολής διαφανειών με δισδιάστατα και τρισδιάστατα εφέ με χρήση του OpenGL
Comment[en_GB]=A tool to slide images with 2D and 3D effects using OpenGL
Comment[es]=Una herramienta para presentar imágenes con efectos OpenGL en 2D y 3D
Comment[et]=Tööriist piltide kahe- ja kolmemõõtmeliste efektidega slaidiseansside loomiseks OpenGL abil
Comment[eu]=Irudiak aurkezteko tresna bat 2D eta 3D efektuekin OpenGL erabiliz
Comment[fr]=Outil de diaporama avec effets OpenGL en 2D et 3D
Comment[gl]=Unha ferramenta para presentar imaxes con efectos 2D e 3D empregando OpenGL
Comment[hu]=Egy eszköz képek vetítéséhez 2D és 3D hatásokkal OpenGL használatával
Comment[is]=Verkfæri til að gera skyggnusýningu  með 2D og 3D áhrifum í OpenGL
Comment[it]=Uno strumento per fare una presentazione con delle immagini usando effetti a due e tre dimensioni con OpenGL
Comment[ja]=OpenGL を使って 2D や 3D 効果付きのスライドショーを作成するツール
Comment[km]=ឧបករណ៍​សម្រាប់​​ដាក់​រូបភាព​ជា​ស្លាយ​ដោយ​ប្រើ​បែបផែន​ទ្វេ​មាត្រ និង​ត្រីមាត្រ​ ដោយ​ប្រើ OpenGL
Comment[lv]=Rīks attēlu rādīšanai ar 2D un 3D efektiem, izmantojot OpenGL
Comment[nb]=Et verktøy for bildeframvisning med 2D- eller 3D-effekter ved bruk av OpenGL
Comment[nds]=En Warktüüch, mit dat sik Biller över OpenGL mit 2D- un 3D-Effekten as Dias wiesen laat
Comment[nl]=Een hulpmiddel voor het maken van dia's met 2D en 3D effecten met behulp van OpenGL
Comment[pa]=OpenGL ਦੀ ਵਰਤੋਂ ਕਰਕੇ 2Dਤੇ 3D ਪਰਭਾਵ ਨਾਲ ਚਿੱਤਰਾਂ ਸਲਾਈਡ ਵੇਖਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do pokazu slajdów z efektami 2D i 3D wykorzystującymi OpenGL
Comment[pt]=Uma ferramenta para apresentar imagens com efeitos do OpenGL em 2D e 3D
Comment[pt_BR]=Uma ferramenta para apresentar slides de imagens com efeitos 2D e 3D usando OpenGL
Comment[ro]=O unealtă de diaporamă cu efecte OpenGL în 2D și 3D
Comment[ru]=Инструмент для перелистывания изображений с использованием плоских и трёхмерных эффектов на основе OpenGL
Comment[sk]=Nástroj na prezentáciu obrázkov s využitím 2D a 3D OpenGL efektov
Comment[sl]=Orodje za prehode slik z 2D in 3D učinki z uporabo OpenGL
Comment[sq]=Një mjet për të shfaqur imazhet me efektet 2D apo 3D duke përdorur OpenGL
Comment[sv]=Ett verktyg för bildspel med två- och tredimensionella effekter som använder OpenGL
Comment[th]=เครื่องมือนำเสนอภาพในรูปแบบ 2 และ 3 มิติ โดยใช้ OpenGL
Comment[tr]=OpenGL kullanarak resimleri 2B vee 3B efektlerle slayt haline getirmek için bir araç
Comment[uk]=Інструмент для створення показу слайдів з ефектами 2D і 3D за допомогою OpenGL
Comment[x-test]=xxA tool to slide images with 2D and 3D effects using OpenGLxx
Comment[zh_CN]=一个使用 OpenGL 2D 和 3D 效果幻灯播放图像的工具
Comment[zh_TW]=使用 OpenGL 2D 和 3D 效果的影像放映工具
Type=Service
Icon=slideshow
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_advancedslideshow
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-MergeMenu=true
author=Renchi Raju, renchi dot raju at gmail dot com

==> digikam-3.1.0.tar.bz2: digikam-3.1.0/extra/kipi-plugins/advancedslideshow/plugin/kipiplugin_advancedslideshow.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Advanced Slideshow
Name=Advanced Slideshow
Name[ast]=Presentación de diapositives avanzaes
Name[bg]=Подробна прожекция
Name[bs]=Napredni slideshow
Name[ca]=Passi de diapositives avançat
Name[ca@valencia]=Passe de diapositives avançat
Name[cs]=Pokročilé promítání
Name[da]=Avanceret diasshow
Name[de]=Erweiterte Diaschau
Name[el]=Προχωρημένη προβολή διαφανειών
Name[en_GB]=Advanced Slideshow
Name[es]=Presentación avanzada
Name[et]=Täiustatud slaidiseanss
Name[eu]=Diapositiba-aurkezpen aurreratua
Name[fi]=Advanced Slideshow
Name[fr]=Diaporama avancé
Name[ga]=Ardtaispeántas Sleamhnán
Name[gl]=Presentación avanzada
Name[hu]=Speciális diavetítés
Name[is]=Ítarlegri skyggnusýning
Name[it]=Presentazione avanzata
Name[ja]=高度なスライドショー
Name[km]=ការ​បញ្ចាំង​ស្លាយ​កម្រិត​ខ្ពស់
Name[lv]=Paplašinātā slīdrāde
Name[nb]=Avansert bildeframvisning
Name[nds]=Verwiedert Diaschau...
Name[nl]=Geavanceerde diavoorstelling
Name[pa]=ਮਾਹਰ ਸਲਾਈਡ-ਸ਼ੋ
Name[pl]=Zaawansowany pokaz slajdów
Name[pt]=Apresentação Avançada
Name[pt_BR]=Apresentação de slides avançada
Name[ro]=Diaporamă avansată
Name[ru]=Многофункциональное слайд-шоу
Name[sk]=Pokročilá prezentácia
Name[sl]=Napredna predstavitev
Name[sq]=Shfaqje e Avancuar
Name[sv]=Avancerat bildspel
Name[th]=การนำเสนอภาพขั้นสูง
Name[tr]=Gelişmiş Slayt Gösterisi
Name[uk]=Показ слайдів з додатковими можливостями
Name[x-test]=xxAdvanced Slideshowxx
Name[zh_CN]=高级幻灯片
Name[zh_TW]=進階投影片放映
Comment=A tool to slide images with 2D and 3D effects using OpenGL
Comment[ast]=Una ferramienta pa diapositives con efeutos en 2D y 3D emplegando OpenGL
Comment[bg]=Инструмент за прожекции на изображения с дву- и итриизмерни ефекти
Comment[bs]=Alat za projekciju slika sa 2D i 3D efektima koristeći OpenGL
Comment[ca]=Una eina per fer dispositives d'imatges amb efectes 2D i 3D utilitzant l'OpenGL
Comment[ca@valencia]=Una eina per fer dispositives d'imatges amb efectes 2D i 3D utilitzant l'OpenGL
Comment[cs]=Nástroj na prohlížení obrázků s 2D a 3D efekty pomocí OpenGL
Comment[da]=Et værktøj til at vise et diasshow med 2D- og 3D-effekter vha. OpenGL
Comment[de]=Ein Werkzeug, um Bilder in einer Diaschau mit 2D- und 3D-Effekten anzuzeigen.
Comment[el]=Εργαλείο προβολής διαφανειών με δισδιάστατα και τρισδιάστατα εφέ με χρήση του OpenGL
Comment[en_GB]=A tool to slide images with 2D and 3D effects using OpenGL
Comment[es]=Una herramienta para presentar imágenes con efectos OpenGL en 2D y 3D
Comment[et]=Tööriist piltide kahe- ja kolmemõõtmeliste efektidega slaidiseansside loomiseks OpenGL abil
Comment[eu]=Irudiak aurkezteko tresna bat 2D eta 3D efektuekin OpenGL erabiliz
Comment[fr]=Outil de diaporama avec effets OpenGL en 2D et 3D
Comment[gl]=Unha ferramenta para presentar imaxes con efectos 2D e 3D empregando OpenGL
Comment[hu]=Egy eszköz képek vetítéséhez 2D és 3D hatásokkal OpenGL használatával
Comment[is]=Verkfæri til að gera skyggnusýningu  með 2D og 3D áhrifum í OpenGL
Comment[it]=Uno strumento per fare una presentazione con delle immagini usando effetti a due e tre dimensioni con OpenGL
Comment[ja]=OpenGL を使って 2D や 3D 効果付きのスライドショーを作成するツール
Comment[km]=ឧបករណ៍​សម្រាប់​​ដាក់​រូបភាព​ជា​ស្លាយ​ដោយ​ប្រើ​បែបផែន​ទ្វេ​មាត្រ និង​ត្រីមាត្រ​ ដោយ​ប្រើ OpenGL
Comment[lv]=Rīks attēlu rādīšanai ar 2D un 3D efektiem, izmantojot OpenGL
Comment[nb]=Et verktøy for bildeframvisning med 2D- eller 3D-effekter ved bruk av OpenGL
Comment[nds]=En Warktüüch, mit dat sik Biller över OpenGL mit 2D- un 3D-Effekten as Dias wiesen laat
Comment[nl]=Een hulpmiddel voor het maken van dia's met 2D en 3D effecten met behulp van OpenGL
Comment[pa]=OpenGL ਦੀ ਵਰਤੋਂ ਕਰਕੇ 2Dਤੇ 3D ਪਰਭਾਵ ਨਾਲ ਚਿੱਤਰਾਂ ਸਲਾਈਡ ਵੇਖਣ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do pokazu slajdów z efektami 2D i 3D wykorzystującymi OpenGL
Comment[pt]=Uma ferramenta para apresentar imagens com efeitos do OpenGL em 2D e 3D
Comment[pt_BR]=Uma ferramenta para apresentar slides de imagens com efeitos 2D e 3D usando OpenGL
Comment[ro]=O unealtă de diaporamă cu efecte OpenGL în 2D și 3D
Comment[ru]=Инструмент для перелистывания изображений с использованием плоских и трёхмерных эффектов на основе OpenGL
Comment[sk]=Nástroj na prezentáciu obrázkov s využitím 2D a 3D OpenGL efektov
Comment[sl]=Orodje za prehode slik z 2D in 3D učinki z uporabo OpenGL
Comment[sq]=Një mjet për të shfaqur imazhet me efektet 2D apo 3D duke përdorur OpenGL
Comment[sv]=Ett verktyg för bildspel med två- och tredimensionella effekter som använder OpenGL
Comment[th]=เครื่องมือนำเสนอภาพในรูปแบบ 2 และ 3 มิติ โดยใช้ OpenGL
Comment[tr]=OpenGL kullanarak resimleri 2B vee 3B efektlerle slayt haline getirmek için bir araç
Comment[uk]=Інструмент для створення показу слайдів з ефектами 2D і 3D за допомогою OpenGL
Comment[x-test]=xxA tool to slide images with 2D and 3D effects using OpenGLxx
Comment[zh_CN]=一个使用 OpenGL 2D 和 3D 效果幻灯播放图像的工具
Comment[zh_TW]=使用 OpenGL 2D 和 3D 效果的影像放映工具
Type=Service
Icon=slideshow
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_advancedslideshow
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
X-KIPI-MergeMenu=true
author=Renchi Raju, renchi dot raju at gmail dot com
